==> openshift-model-console-4.11.0-sources.jar: annotations/io/fabric8/openshift/api/model/console/v1/ConsoleCLIDownloadSpecFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ConsoleCLIDownloadSpecFluent<A extends ConsoleCLIDownloadSpecFluent<A>> extends Fluent<A>{


    public String getDescription();
    public A withDescription(String description);
    public Boolean hasDescription();
    public A withNewDescription(String arg1);
    public A withNewDescription(StringBuilder arg1);
    public A withNewDescription(StringBuffer arg1);
    public String getDisplayName();
    public A withDisplayName(String displayName);
    public Boolean hasDisplayName();
    public A withNewDisplayName(String arg1);
    public A withNewDisplayName(StringBuilder arg1);
    public A withNewDisplayName(StringBuffer arg1);
    public A addToLinks(int index,CLIDownloadLink item);
    public A setToLinks(int index,CLIDownloadLink item);
    public A addToLinks(CLIDownloadLink... items);
    public A addAllToLinks(Collection<CLIDownloadLink> items);
    public A removeFromLinks(CLIDownloadLink... items);
    public A removeAllFromLinks(Collection<CLIDownloadLink> items);
    public A removeMatchingFromLinks(io.fabric8.kubernetes.api.builder.Predicate<CLIDownloadLinkBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildLinks instead.
 * @return The buildable object.
 */
@Deprecated public List<CLIDownloadLink> getLinks();
    public List<CLIDownloadLink> buildLinks();
    public CLIDownloadLink buildLink(int index);
    public CLIDownloadLink buildFirstLink();
    public CLIDownloadLink buildLastLink();
    public CLIDownloadLink buildMatchingLink(io.fabric8.kubernetes.api.builder.Predicate<CLIDownloadLinkBuilder> predicate);
    public Boolean hasMatchingLink(io.fabric8.kubernetes.api.builder.Predicate<CLIDownloadLinkBuilder> predicate);
    public A withLinks(List<CLIDownloadLink> links);
    public A withLinks(CLIDownloadLink... links);
    public Boolean hasLinks();
    public A addNewLink(String href,String text);
    public ConsoleCLIDownloadSpecFluent.LinksNested<A> addNewLink();
    public ConsoleCLIDownloadSpecFluent.LinksNested<A> addNewLinkLike(CLIDownloadLink item);
    public ConsoleCLIDownloadSpecFluent.LinksNested<A> setNewLinkLike(int index,CLIDownloadLink item);
    public ConsoleCLIDownloadSpecFluent.LinksNested<A> editLink(int index);
    public ConsoleCLIDownloadSpecFluent.LinksNested<A> editFirstLink();
    public ConsoleCLIDownloadSpecFluent.LinksNested<A> editLastLink();
    public ConsoleCLIDownloadSpecFluent.LinksNested<A> editMatchingLink(io.fabric8.kubernetes.api.builder.Predicate<CLIDownloadLinkBuilder> predicate);

    public interface LinksNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CLIDownloadLinkFluent<ConsoleCLIDownloadSpecFluent.LinksNested<N>>{

        
    public N and();    public N endLink();
}


}

==> openshift-model-console-5.0.2-sources.jar: annotations/io/fabric8/openshift/api/model/console/v1/ConsoleCLIDownloadSpecFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ConsoleCLIDownloadSpecFluent<A extends ConsoleCLIDownloadSpecFluent<A>> extends Fluent<A> {


    public String getDescription();
    public A withDescription(String description);
    public Boolean hasDescription();
    public A withNewDescription(String arg1);
    public A withNewDescription(StringBuilder arg1);
    public A withNewDescription(StringBuffer arg1);
    public String getDisplayName();
    public A withDisplayName(String displayName);
    public Boolean hasDisplayName();
    public A withNewDisplayName(String arg1);
    public A withNewDisplayName(StringBuilder arg1);
    public A withNewDisplayName(StringBuffer arg1);
    public A addToLinks(int index,CLIDownloadLink item);
    public A setToLinks(int index,CLIDownloadLink item);
    public A addToLinks(CLIDownloadLink... items);
    public A addAllToLinks(Collection<CLIDownloadLink> items);
    public A removeFromLinks(CLIDownloadLink... items);
    public A removeAllFromLinks(Collection<CLIDownloadLink> items);
    public A removeMatchingFromLinks(Predicate<CLIDownloadLinkBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildLinks instead.
 * @return The buildable object.
 */
@Deprecated public List<CLIDownloadLink> getLinks();
    public List<CLIDownloadLink> buildLinks();
    public CLIDownloadLink buildLink(int index);
    public CLIDownloadLink buildFirstLink();
    public CLIDownloadLink buildLastLink();
    public CLIDownloadLink buildMatchingLink(Predicate<CLIDownloadLinkBuilder> predicate);
    public Boolean hasMatchingLink(Predicate<CLIDownloadLinkBuilder> predicate);
    public A withLinks(List<CLIDownloadLink> links);
    public A withLinks(CLIDownloadLink... links);
    public Boolean hasLinks();
    public A addNewLink(String href,String text);
    public ConsoleCLIDownloadSpecFluent.LinksNested<A> addNewLink();
    public ConsoleCLIDownloadSpecFluent.LinksNested<A> addNewLinkLike(CLIDownloadLink item);
    public ConsoleCLIDownloadSpecFluent.LinksNested<A> setNewLinkLike(int index,CLIDownloadLink item);
    public ConsoleCLIDownloadSpecFluent.LinksNested<A> editLink(int index);
    public ConsoleCLIDownloadSpecFluent.LinksNested<A> editFirstLink();
    public ConsoleCLIDownloadSpecFluent.LinksNested<A> editLastLink();
    public ConsoleCLIDownloadSpecFluent.LinksNested<A> editMatchingLink(Predicate<CLIDownloadLinkBuilder> predicate);
    public interface LinksNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CLIDownloadLinkFluent<ConsoleCLIDownloadSpecFluent.LinksNested<N>> {

            public N and();
            public N endLink();    }


}
